use super::{run_chroot, Image};
use crate::setup::Setup;

pub fn install_packages(img: &Image, setup: &Setup) -> anyhow::Result<()> {
	eprintln!("Installing packages ...");

	for pkg in &setup.packages.install {
		run_chroot(img, "root", ["apk", "add", pkg])?;
	}

	for service in &setup.packages.autostart {
		run_chroot(img, "root", ["rc-update", "add", service, "default"])?;
	}

	Ok(())
}

pub fn install_autostart(img: &Image, setup: &Setup) -> anyhow::Result<()> {
	if let Some(kiosk) = &setup.autostart.kiosk {
		eprintln!("Installing kiosk ...");
		run_chroot(img, "root", [
			"apk",
			"add",
			"cage",
			"firefox",
			"font-noto",
			"mesa-dri-gallium",
			"polkit",
			"polkit-elogind"
		])?;
		run_chroot(img, "root", [
			"sed",
			"-E",
			"-i",
			"-e",
			&format!("/tty1/s,agetty,agetty --autologin {},", kiosk.user),
			"/etc/inittab"
		])?;
		run_chroot(img, &kiosk.user, "[ -e ~/.profile ] || echo '#!/bin/busybox ash' >~/.profile")?;
		run_chroot(
			img,
			&kiosk.user,
			format!(
				r#"echo 'if [ "$(tty)" == "/dev/tty1" ]; then dbus-run-session cage firefox --kiosk "{}"; fi' >>~/.profile"#,
				kiosk.page
			)
			.as_str()
		)?;
	}

	Ok(())
}
